==> apache-iceberg-1.9.1.tar.gz: apache-iceberg-1.9.1/azure/src/main/java/org/apache/iceberg/azure/adlsv2/BaseADLSFile.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.azure.adlsv2;

import com.azure.storage.file.datalake.DataLakeFileClient;
import org.apache.iceberg.azure.AzureProperties;
import org.apache.iceberg.metrics.MetricsContext;
import org.apache.iceberg.relocated.com.google.common.base.Preconditions;

abstract class BaseADLSFile {
  private final String location;
  private final DataLakeFileClient fileClient;
  private final AzureProperties azureProperties;
  private final MetricsContext metrics;

  BaseADLSFile(
      String location,
      DataLakeFileClient fileClient,
      AzureProperties azureProperties,
      MetricsContext metrics) {
    Preconditions.checkArgument(location != null, "Cannot initialize ADLS file with null location");
    Preconditions.checkArgument(
        fileClient != null, "Cannot initialize ADLS file with null file client");
    Preconditions.checkArgument(
        azureProperties != null, "Cannot initialize ADLS file with null properties");
    Preconditions.checkArgument(metrics != null, "Cannot initialize ADLS file with null metrics");
    this.location = location;
    this.fileClient = fileClient;
    this.azureProperties = azureProperties;
    this.metrics = metrics;
  }

  protected AzureProperties azureProperties() {
    return azureProperties;
  }

  protected MetricsContext metrics() {
    return metrics;
  }

  protected DataLakeFileClient fileClient() {
    return fileClient;
  }

  public String location() {
    return location;
  }

  public boolean exists() {
    return fileClient().exists();
  }

  @Override
  public String toString() {
    return location;
  }
}

==> apache-iceberg-1.10.1.tar.gz: apache-iceberg-1.10.1/azure/src/main/java/org/apache/iceberg/azure/adlsv2/BaseADLSFile.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.azure.adlsv2;

import com.azure.storage.file.datalake.DataLakeFileClient;
import org.apache.iceberg.azure.AzureProperties;
import org.apache.iceberg.metrics.MetricsContext;
import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

abstract class BaseADLSFile {
  private static final Logger LOG = LoggerFactory.getLogger(BaseADLSFile.class);

  private final String location;
  private final DataLakeFileClient fileClient;
  private final AzureProperties azureProperties;
  private final MetricsContext metrics;

  BaseADLSFile(
      String location,
      DataLakeFileClient fileClient,
      AzureProperties azureProperties,
      MetricsContext metrics) {
    Preconditions.checkArgument(location != null, "Cannot initialize ADLS file with null location");
    Preconditions.checkArgument(
        fileClient != null, "Cannot initialize ADLS file with null file client");
    Preconditions.checkArgument(
        azureProperties != null, "Cannot initialize ADLS file with null properties");
    Preconditions.checkArgument(metrics != null, "Cannot initialize ADLS file with null metrics");
    this.location = location;
    this.fileClient = fileClient;
    this.azureProperties = azureProperties;
    this.metrics = metrics;
  }

  protected AzureProperties azureProperties() {
    return azureProperties;
  }

  protected MetricsContext metrics() {
    return metrics;
  }

  protected DataLakeFileClient fileClient() {
    return fileClient;
  }

  public String location() {
    return location;
  }

  public boolean exists() {
    try {
      return fileClient().exists();
    } catch (RuntimeException e) {
      LOG.error("Failed to check if the file exists at path {}", location, e);
      throw e;
    }
  }

  @Override
  public String toString() {
    return location;
  }
}
